@@ -2,13 +2,13 @@ package LCFG::Build::VCS;   # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: VCS.pm.in 29257 2015-11-12 15:42:14Z squinney@INF.ED.AC.UK $
+# $Id: VCS.pm.in 31796 2017-01-19 13:31:51Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-VCS/lib/LCFG/Build/VCS.pm.in,v $
-# $Revision: 29257 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-VCS/LCFG_Build_VCS_0_2_2/lib/LCFG/Build/VCS.pm.in $
-# $Date: 2015-11-12 15:42:14 +0000 (Thu, 12 Nov 2015) $
+# $Revision: 31796 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-VCS/LCFG_Build_VCS_0_2_3/lib/LCFG/Build/VCS.pm.in $
+# $Date: 2017-01-19 13:31:51 +0000 (Thu, 19 Jan 2017) $
 
-our $VERSION = '0.2.2';
+our $VERSION = '0.2.3';
 
 use DateTime ();
 use File::Copy ();
@@ -57,7 +57,7 @@ has 'workdir' => (
 
 has 'binpath' => (
     is       => 'rw',
-    isa      => 'Maybe[AbsPath]',
+    isa      => 'Str',
     required => 0,
 );
 
@@ -261,7 +261,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::VCS version 0.2.2
+    This documentation refers to LCFG::Build::VCS version 0.2.3
 
 =head1 SYNOPSIS
 
@@ -313,7 +313,7 @@ automatically occur based on the current working directory.
 
 The path to the version-control tool. This is required and it is
 expected that any module which implements this interface will set a
-suitable default path. This must be an absolute path.
+suitable default command name.
 
 =item quiet
 
