@@ -2,13 +2,13 @@ package LCFG::Build::VCS::CVS;  # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: CVS.pm.in 29257 2015-11-12 15:42:14Z squinney@INF.ED.AC.UK $
+# $Id: CVS.pm.in 31796 2017-01-19 13:31:51Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-VCS/lib/LCFG/Build/VCS/CVS.pm.in,v $
-# $Revision: 29257 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-VCS/LCFG_Build_VCS_0_2_2/lib/LCFG/Build/VCS/CVS.pm.in $
-# $Date: 2015-11-12 15:42:14 +0000 (Thu, 12 Nov 2015) $
+# $Revision: 31796 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-VCS/LCFG_Build_VCS_0_2_3/lib/LCFG/Build/VCS/CVS.pm.in $
+# $Date: 2017-01-19 13:31:51 +0000 (Thu, 19 Jan 2017) $
 
-our $VERSION = '0.2.2';
+our $VERSION = '0.2.3';
 
 use Cwd            ();
 use File::Find     ();
@@ -20,7 +20,7 @@ use Try::Tiny;
 use Moose;
 with 'LCFG::Build::VCS';
 
-has '+binpath' => ( default => '/usr/bin/cvs' );
+has '+binpath' => ( default => 'cvs' );
 
 has 'root' => (
     is      => 'rw',
@@ -377,7 +377,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::VCS::CVS version 0.2.2
+    This documentation refers to LCFG::Build::VCS::CVS version 0.2.3
 
 =head1 SYNOPSIS
 
@@ -429,8 +429,7 @@ current working directory.
 
 =item binpath
 
-The path to the CVS executable, by default this is /usr/bin/cvs. If
-you want to alter this it must be set to an absolute path.
+The name of the CVS executable, by default this is C<cvs>.
 
 =item root
 
